import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()
    
def _requires_from_file(filename):
    return open(filename, encoding="utf8").read().splitlines()

extras_require = {
    "async": [
        "aiohttp>=3.8.1"
    ]
}

setuptools.setup(
    name="google-custom-search",
    version="2.0.5a",
    author="DMS",
    author_email="masato190411@gmail.com",
    description="This is for google custom search api.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/tuna2134/google-custom-search",
    install_requires=_requires_from_file('requirements.txt'),
    extras_require=extras_require,
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



# __all__ = ("Item")
import json


class Item:
    """This is return a item."""
    def __init__(self, data: dict):
        self.data: dict = data
            
    @property
    def kind(self) -> str:
        "This is the kind of the item."
        return self.data["kind"]
    
    @property
    def title(self) -> str:
        "This is the title of the item."
        return self.data["title"]
    
    @property
    def url(self) -> str:
        "This is the url of the item."
        return self.data["link"]
    
    @property
    def display_url(self) -> str:
        "This is the display url of the item."
        return self.data["displayLink"]
    
    @property
    def html_title(self) -> str:
        "This is the html title of the item."
        return self.data["htmlTitle"]
    
    @property
    def snippet(self) -> str:
        "This is the snippet of the item."
        return self.data["snippet"]
